# localization

# region common
l_on = {
    'ru': "вкл",
    'en': "on",
    'es': "en",
    'fr': "sur",
    'zh': "上",
    'ar': "على",
}
l_off = {
    'ru': "выкл",
    'en': "off",
    'es': "apagado",
    'fr': "à l'arrêt",
    'zh': "離開",
    'ar': "إيقاف",
}
l_yes = {
    'ru': "да",
    'en': "off",
    'es': "sí",
    'fr': "oui",
    'zh': "是的",
    'ar': "نعم",
}
l_no = {
    'ru': "нет",
    'en': "no",
    'es': "no",
    'fr': "non",
    'zh': "不",
    'ar': "رقم",
}
l_yes_percent = {
    'ru': "👩🏽‍💻 Да, 100%",
    'en': "👩🏽‍💻 Yes, 100%",
    'es': "👩🏽‍💻 Sí, 100%",
    'fr': "👩🏽‍💻 Oui, 100%",
    'zh': "👩🏽‍💻 的，100%",
    'ar': "▪️ نعم ، 100٪",
}
l_no_percent = {
    'ru': "👩🏽‍💻 Нет, 0%",
    'en': "👩🏽‍💻 No, 0%",
    'es': "👩🏽‍💻 No, 0%",
    'fr': "👩🏽‍💻 Non, 0%",
    'zh': "👩🏽‍💻 不，0%",
    'ar': "👩🏽‍💻  لا ، 0٪",
}
l_creturn_text = {
    'ru': "✖️ Сбросить настройки по умолчанию (до рекомендуемых) для канала [<b>{0}</b>]?",
    'en': "✖️ Restore settings to default for channel [<b>{0}</b>]?",
    'es': "✖️ ¿Restaurar la configuración predeterminada para el grupo [<b>{0}</b>]?",
    'fr': "✖️ Restaurer les paramètres par défaut pour le channele [<b>{0}</b>] ?",
    'zh': "✖️ 將組 [<b>{0}</b>] 的設置恢復為默認設置？",
    'ar': "✖️ هل تريد استعادة الإعدادات الافتراضية للمجموعة [<b>{0}</b>]؟",
}
l_all_ans = {
    'ru': "все",
    'en': "all",
    'es': "no",
    'fr': "non",
    'zh': "不",
    'ar': "رقم",
}
l_menu = {
    'ru': "🔙 Меню",
    'en': "🔙️ Back",
    'es': "🔙 Volver",
    'fr': "🔙 Retour",
    'zh': "🔙 回來",
    'ar': "🔙 رجوع",
}
l_forever = {
    'ru': "навсегда",
    'en': "forever",
    'es': "siempre",
    'fr': "toujours",
    'zh': "永遠",
    'ar': "إلى الأبد",
}

l_choose_direction = {
    'ru': '👇🏽 <b>Выбери</b> направление',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_about = {
    'ru': "<b>🦋 Автоворонки & чат-боты в SocialMedia</b> для:\n\n▪️таргета: @ferey_send_bot\n▪️поиска: @ferey_find_bot\n▪️постов: @ferey_post_bot\n▪️автоответов: @ferey_user_bot\n▪️канала: @ferey_chat_bot\n▪️канала: @ferey_channel_bot\n▪️рекламы: @ferey_advert_bot\n\n❗️все боты общедоступны & для общего пользования",
    'en': f"<b>🦋 Аuto-funnel & chat-bots in SocialMedia</b> for:\n\n▪️target: @ferey_send_bot\n▪️search: @ferey_find_bot\n▪️post: @ferey_post_bot\n▪️auto-answer: @ferey_user_bot\n▪️channel: @ferey_chat_bot\n▪️channel: @ferey_channel_bot\n▪️advert: @ferey_advert_bot\n\n❗️All bots are public & for common use",
    'es': f"<b>🦋 Embudo automático & bots de chat en redes sociales</b> para:\n\n▪️objetivo: @ferey_send_bot\n▪️búsqueda: @ferey_find_bot\n▪️publicación: @ferey_post_bot\n▪️respuesta automática: @ferey_user_bot\n▪️grupo: @ferey_chat_bot\n▪️canal: @ferey_channel_bot\n▪️anuncio: @ferey_advert_bot\n\n❗️Todos los bots son públicos y de uso común",
    'fr': f"<b>🦋 Аuto-entonnoir & chat-bots dans les médias sociaux</b> pour :\n\n▪️cible : @ferey_send_bot\n▪️recherche : @ferey_find_bot\n▪️post : @ferey_post_bot\n▪️réponse automatique : @ferey_user_bot\n▪️channele : @ferey_chat_bot\n▪️canal : @ferey_channel_bot\n▪️annonce : @ferey_advert_bot\n\n❗️Tous les bots sont publics et à usage commun",
    'zh': f"<b>🦋 社交媒體中的自動漏斗和聊天機器人</b> 為了:\n\n▪️目標: @ferey_send_bot\n▪️搜索: @ferey_find_bot\n▪️優惠: @ferey_post_bot\n▪️自動應答: @ferey_user_bot\n▪️組: @ferey_chat_bot\n▪️頻道: @ferey_channel_bot\n▪️廣告: @ferey_advert_bot\n\n❗️️所有機器人都是公開的 & 普通用途",
    'ar': f"<b>🦋 التحويل التلقائي وروبوتات الدردشة في وسائل التواصل الاجتماعي</b> إلى عن على:\n\n▪️ الهدف: @ferey_send_bot\n▪️ البحث: @ferey_find_bot\n▪️ آخر: @ferey_post_bot\n▪️رد ألي: @ferey_user_bot\n▪️المجموعة: @ferey_chat_bot\n▪️القناة: @ferey_channel_bot\n▪️ادفع: @ferey_advert_bot\n\n❗️جميع الروبوتات عامة & للاستخدام الشائع",
}
l_subscribe = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную <i>подписку</i>\n\n¹ на @{0}-бота [{1} ₽]\n▪️ отсутствие рекламы\n▪️ творческие задания\n² Подписка на <u>всех</u> ботов [{2} ₽]",
    'en': f"<b>🦋 Аuto-funnel & chat-bots in SocialMedia</b> for:\n\n▪️target: @ferey_send_bot\n▪️search: @ferey_find_bot\n▪️post: @ferey_post_bot\n▪️auto-answer: @ferey_user_bot\n▪️channel: @ferey_chat_bot\n▪️channel: @ferey_channel_bot\n▪️advert: @ferey_advert_bot\n\n❗️All bots are public & for common use",
    'es': f"<b>🦋 Embudo automático & bots de chat en redes sociales</b> para:\n\n▪️objetivo: @ferey_send_bot\n▪️búsqueda: @ferey_find_bot\n▪️publicación: @ferey_post_bot\n▪️respuesta automática: @ferey_user_bot\n▪️grupo: @ferey_chat_bot\n▪️canal: @ferey_channel_bot\n▪️anuncio: @ferey_advert_bot\n\n❗️Todos los bots son públicos y de uso común",
    'fr': f"<b>🦋 Аuto-entonnoir & chat-bots dans les médias sociaux</b> pour :\n\n▪️cible : @ferey_send_bot\n▪️recherche : @ferey_find_bot\n▪️post : @ferey_post_bot\n▪️réponse automatique : @ferey_user_bot\n▪️channele : @ferey_chat_bot\n▪️canal : @ferey_channel_bot\n▪️annonce : @ferey_advert_bot\n\n❗️Tous les bots sont publics et à usage commun",
    'zh': f"<b>🦋 社交媒體中的自動漏斗和聊天機器人</b> 為了:\n\n▪️目標: @ferey_send_bot\n▪️搜索: @ferey_find_bot\n▪️優惠: @ferey_post_bot\n▪️自動應答: @ferey_user_bot\n▪️組: @ferey_chat_bot\n▪️頻道: @ferey_channel_bot\n▪️廣告: @ferey_advert_bot\n\n❗️️所有機器人都是公開的 & 普通用途",
    'ar': f"<b>🦋 التحويل التلقائي وروبوتات الدردشة في وسائل التواصل الاجتماعي</b> إلى عن على:\n\n▪️ الهدف: @ferey_send_bot\n▪️ البحث: @ferey_find_bot\n▪️ آخر: @ferey_post_bot\n▪️رد ألي: @ferey_user_bot\n▪️المجموعة: @ferey_chat_bot\n▪️القناة: @ferey_channel_bot\n▪️ادفع: @ferey_advert_bot\n\n❗️جميع الروبوتات عامة & للاستخدام الشائع",
}
l_subscribe_btn = {
    'ru': "👩🏽‍💻 Я подписался",
    'en': f"<b>🦋 Аuto-funnel & chat-bots in SocialMedia</b> for:\n\n▪️target: @ferey_send_bot\n▪️search: @ferey_find_bot\n▪️post: @ferey_post_bot\n▪️auto-answer: @ferey_user_bot\n▪️channel: @ferey_chat_bot\n▪️channel: @ferey_channel_bot\n▪️advert: @ferey_advert_bot\n\n❗️All bots are public & for common use",
    'es': f"<b>🦋 Embudo automático & bots de chat en redes sociales</b> para:\n\n▪️objetivo: @ferey_send_bot\n▪️búsqueda: @ferey_find_bot\n▪️publicación: @ferey_post_bot\n▪️respuesta automática: @ferey_user_bot\n▪️grupo: @ferey_chat_bot\n▪️canal: @ferey_channel_bot\n▪️anuncio: @ferey_advert_bot\n\n❗️Todos los bots son públicos y de uso común",
    'fr': f"<b>🦋 Аuto-entonnoir & chat-bots dans les médias sociaux</b> pour :\n\n▪️cible : @ferey_send_bot\n▪️recherche : @ferey_find_bot\n▪️post : @ferey_post_bot\n▪️réponse automatique : @ferey_user_bot\n▪️channele : @ferey_chat_bot\n▪️canal : @ferey_channel_bot\n▪️annonce : @ferey_advert_bot\n\n❗️Tous les bots sont publics et à usage commun",
    'zh': f"<b>🦋 社交媒體中的自動漏斗和聊天機器人</b> 為了:\n\n▪️目標: @ferey_send_bot\n▪️搜索: @ferey_find_bot\n▪️優惠: @ferey_post_bot\n▪️自動應答: @ferey_user_bot\n▪️組: @ferey_chat_bot\n▪️頻道: @ferey_channel_bot\n▪️廣告: @ferey_advert_bot\n\n❗️️所有機器人都是公開的 & 普通用途",
    'ar': f"<b>🦋 التحويل التلقائي وروبوتات الدردشة في وسائل التواصل الاجتماعي</b> إلى عن على:\n\n▪️ الهدف: @ferey_send_bot\n▪️ البحث: @ferey_find_bot\n▪️ آخر: @ferey_post_bot\n▪️رد ألي: @ferey_user_bot\n▪️المجموعة: @ferey_chat_bot\n▪️القناة: @ferey_channel_bot\n▪️ادفع: @ferey_advert_bot\n\n❗️جميع الروبوتات عامة & للاستخدام الشائع",
}
l_language_get = {
    'ru': "🌏 <b>Выбери</b> один из доступных языков",
    'en': "🌏 Choose language",
    'es': "🌏 Elige idioma",
    'fr': "🌏 Choisissez la langue",
    'zh': "🌏 選擇語言",
    'ar': "🌏 اختر اللغة",
}
l_language_set = {
    'ru': "{0} Текущий язык: {1}",
    'en': "{0} Current language: {1}",
    'es': "{0} Idioma actual: {1}",
    'fr': "{0} Langue actuelle : {1}",
    'zh': "{0} 當前語言: {1}",
    'ar': "{0} اللغة الحالية: {1}",
}
l_ferey_like = {
    'ru': "💔 Like",
    'en': "💔 Like",
    'es': "💔 Like",
    'fr': "💔 Like",
    'zh': "💔 Like",
    'ar': "💔 Like",
}
# endregion


# region FereyDemoBot
l_demo_btn1 = {
    'ru': '⛰️ Проекты',
    'en': '⛰️ Projects',
    'es': '⛰️ Projects',
    'fr': '⛰️ Projects',
    'zh': '⛰️ 團體',
    'ar': '⛰️ مجموعات',
}
l_demo_btn2 = {
    'ru': '🌬 Подписка',
    'en': '🌬 Subcribe',
    'es': '🌬 Sobre',
    'fr': '🌬 À propos de',
    'zh': '🌬 關於',
    'ar': '🌬 حول',
}
l_demo_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>проекта</code> <b>Ferey</b>:\n\n▪️<b>информация</b> обо всех проектах\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>landing-bot</i> for <code>administration</code> <b>Telegram</b>-channels:\n\n▪️<b>pretecting</b> channel from spy-joining of\n▪️store offers in <b>unique</b> space\n▪️defend offers form <b>auto</b> deleted* \n(*even it has stop-words)\n\n❗️to order chat-bot-development go to <a href='https://t.me/{1}'>Ferey</a>-studio",
    'es': "🌱 {0}, Bienvenida(o) a <i>lugar de aterrizaje-bot</i> por <code>creando & publicando</code> <b>Telegram</b>-Grupos:\n\n▪️️crear <b>cualquier</b> tipo de oferta (con botones)\n▪️almacenar ofertas en un espacio <b>único</b>\n▪️️defend ofrece formulario <b>auto</b> borrado* \n(*incluso tiene palabras vacías)\n\n❗️para ordenar chat-bot-desarrollo vaya a <a href='https://t.me/{1}'>Ferey</a>-estudio",
    'fr': "🌱 {0}, bienvenue sur <i>landing-bot</i> pour la <code>création et publication</code> <b>Télégramme</b>-channeles:\n\n▪️créer <b>tout </b> type d'offre (avec boutons)\n▪️stocker les offres dans un espace <b>unique</b>\n▪️défendre les offres sous forme <b>auto</b> supprimées* \n(*même si elles ont cessé -words)\n\n❗️pour commander le développement de chat-bot, rendez-vous sur <a href='https://t.me/{1}'>Ferey</a>-studio",
    'zh': "🌱 {0}, 歡迎來到 <i>著陸點-bot</i> 為了 <code>創造 & 張貼</code> <b>Telegram</b>-團體:\n\n▪️️創造 <b>任何</b> 報價類型 (帶按鈕)\n▪️商店優惠在 <b>獨特的</b> 獨特的\n▪️捍衛報價表格自動刪除* \n(*捍衛自動刪除的提議)\n\n❗️訂購 Telegram-bot 去 <a href='https://t.me/{1}'>Ferey</a>-工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i> برنامج التتبع </i> من أجل الإنشاء والنش Telegram - مجموعات: \n\n▪️ إنشاء <b> أي </b> نوع العرض (مع الأزرار) \n▪️ عروض المتجر في مساحة فريدة \n▪️ الدفاع عن نموذج عروض <b> تلقائي </b> محذوفة * \n (* حتى إذا توقفت -كلمات) \n\n لطلب تطوير chat-bot-انتقل إلى <a href='https://t.me/{1}'>Ferey</a>-studio"
}

l_kind_1 = {
    'ru': '<b>👩🏽‍💻@FereyDemoBot</b>\n\nДемонстрационный бот всех проектов',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_2 = {
    'ru': '<b>👩🏽‍💻@FereyBotBot</b>\n\nКонструктор ботов:\n▪️авто-генерация бота\n▪️авто-генерация контента (open-ai)\n▪️авто-бан/авто-перевод',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_3 = {
    'ru': '<b>👩🏽‍💻@FereyChannelBot</b>\n\nАдминистратор каналов:\n▪️авто-постинг\n▪️авто-декор',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_4 = {
    'ru': '<b>👩🏽‍💻@FereyGroupBot</b>\n\nАдминистратор групп:\n▪️авто-постинг\n▪️модерация',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_5 = {
    'ru': '<b>👩🏽‍💻@FereyUserBot</b>\n\nАдминистратор пользователей:\n▪️авто-постинг\n▪️авто-декор',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_6 = {
    'ru': '<b>👩🏽‍💻@FereyPostBot</b>\n\nБыстрое создание и публикация постов:\n▪️превью\n▪️галерея',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_7 = {
    'ru': '<b>👩🏽‍💻@FereyFindBot</b>\n\nПоиск по каналам/группам/пользователям/ботам:\n▪️отслеживание постов\n▪️гео-поиск',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_8 = {
    'ru': '<b>👩🏽‍💻@FereyMediaBot</b>\n\nБот с популярными креативами:\n▪️аудио-заметки\n▪️видео-заметки',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_9 = {
    'ru': '<b>👩🏽‍💻@FereyVpnBot</b>\n\nВсе о VPN',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_10 = {
    'ru': '<b>👩🏽‍💻@FereyTargetBot</b>\n\nТаргетированная рассылка',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_11 = {
    'ru': '<b>👩🏽‍💻@FereyToolsBot</b>\n\nБот инструментов:\n▪️конвертация\n▪️загрузка',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_12 = {
    'ru': '<b>👩🏽‍💻@FereyAIBot</b>\n\nБот генерации контента (open-ai):\n▪️chat-gpt\n▪️dalli·e',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_13 = {
    'ru': '<b>👩🏽‍💻@FereyAdsBot</b>\n\nБот рекламы в:\n▪️ботах\n▪️каналах',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_kind_14 = {
    'ru':  '<b>👩🏽‍💻@FereyWorkBot</b>\n\nБот информации о:\n▪️вакансиях\n▪️соревнованиях',
    'en': '👇🏽 Choose direction',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
# endregion


# region FereyWorkBot
l_work_btn1 = {
    'ru': '⛰️ Вакансии',
    'en': '⛰️ Projects',
    'es': '⛰️ Projects',
    'fr': '⛰️ Projects',
    'zh': '⛰️ 團體',
    'ar': '⛰️ مجموعات',
}
l_work_btn2 = {
    'ru': '🌬 Подписка',
    'en': '🌬 Subcribe',
    'es': '🌬 Sobre',
    'fr': '🌬 À propos de',
    'zh': '🌬 關於',
    'ar': '🌬 حول',
}
l_work_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>проекта</code> <b>Ferey</b>:\n\n▪️<b>вакансии</b> нашего стартапа\n▪️конкурсы и <b>мероприятия</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>landing-bot</i> for <code>administration</code> <b>Telegram</b>-channels:\n\n▪️<b>pretecting</b> channel from spy-joining of\n▪️store offers in <b>unique</b> space\n▪️defend offers form <b>auto</b> deleted* \n(*even it has stop-words)\n\n❗️to order chat-bot-development go to <a href='https://t.me/{1}'>Ferey</a>-studio",
    'es': "🌱 {0}, Bienvenida(o) a <i>lugar de aterrizaje-bot</i> por <code>creando & publicando</code> <b>Telegram</b>-Grupos:\n\n▪️️crear <b>cualquier</b> tipo de oferta (con botones)\n▪️almacenar ofertas en un espacio <b>único</b>\n▪️️defend ofrece formulario <b>auto</b> borrado* \n(*incluso tiene palabras vacías)\n\n❗️para ordenar chat-bot-desarrollo vaya a <a href='https://t.me/{1}'>Ferey</a>-estudio",
    'fr': "🌱 {0}, bienvenue sur <i>landing-bot</i> pour la <code>création et publication</code> <b>Télégramme</b>-channeles:\n\n▪️créer <b>tout </b> type d'offre (avec boutons)\n▪️stocker les offres dans un espace <b>unique</b>\n▪️défendre les offres sous forme <b>auto</b> supprimées* \n(*même si elles ont cessé -words)\n\n❗️pour commander le développement de chat-bot, rendez-vous sur <a href='https://t.me/{1}'>Ferey</a>-studio",
    'zh': "🌱 {0}, 歡迎來到 <i>著陸點-bot</i> 為了 <code>創造 & 張貼</code> <b>Telegram</b>-團體:\n\n▪️️創造 <b>任何</b> 報價類型 (帶按鈕)\n▪️商店優惠在 <b>獨特的</b> 獨特的\n▪️捍衛報價表格自動刪除* \n(*捍衛自動刪除的提議)\n\n❗️訂購 Telegram-bot 去 <a href='https://t.me/{1}'>Ferey</a>-工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i> برنامج التتبع </i> من أجل الإنشاء والنش Telegram - مجموعات: \n\n▪️ إنشاء <b> أي </b> نوع العرض (مع الأزرار) \n▪️ عروض المتجر في مساحة فريدة \n▪️ الدفاع عن نموذج عروض <b> تلقائي </b> محذوفة * \n (* حتى إذا توقفت -كلمات) \n\n لطلب تطوير chat-bot-انتقل إلى <a href='https://t.me/{1}'>Ferey</a>-studio"
}
l_vacancy_1 = {
    'ru': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
    'en': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
    'es': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
    'fr': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
    'zh': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
    'ar': '👩🏽‍💻 <b>Text to video ai-designer</b>\n\nTasks: create ferey-masks (realistic video) for any human\nGender: girl\nAge: less than 30\nPay: share of the company',
}
l_vacancy_2 = {
    'ru': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
    'en': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
    'es': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
    'fr': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
    'zh': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
    'ar': '👩🏽‍💻 <b>Content/video maker</b>\n\nTasks: generate creatives for all socials\nGender: girl\nAge: less than 30\nPay: 1 TON per 1 post for all socials',
}
l_vacancy_3 = {
    'ru': '👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
    'en': '👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
    'es': '👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
    'fr': '👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
    'zh':'👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
    'ar': '👩🏽‍💻 <b>Aio/pyro-gram developer</b>\n\nTasks: dev and support all projects\nGender: girl\nAge: less than 30\nPay: share of the company',
}
# endregion


# region FereyAIBot
l_ai_btn1 = {
    'ru': '⛰️ Вакансии',
    'en': '⛰️ Projects',
    'es': '⛰️ Projects',
    'fr': '⛰️ Projects',
    'zh': '⛰️ 團體',
    'ar': '⛰️ مجموعات',
}
l_ai_btn2 = {
    'ru': '🌬 Подписка',
    'en': '🌬 Subcribe',
    'es': '🌬 Sobre',
    'fr': '🌬 À propos de',
    'zh': '🌬 關於',
    'ar': '🌬 حول',
}
l_ai_welcome = {
    'ru': "🌱 {0}, добро пожаловать в <i>лендинг-бот</i> <code>проекта</code> <b>Ferey</b>:\n\n▪️<b>вакансии</b> нашего стартапа\n▪️конкурсы и <b>мероприятия</b>\n\n❗️также можно заказать разработку чат-бота в нашей студии <a href='https://t.me/{1}'>Ferey</a>",
    'en': "🌱 {0}, welcome to <i>landing-bot</i> for <code>administration</code> <b>Telegram</b>-channels:\n\n▪️<b>pretecting</b> channel from spy-joining of\n▪️store offers in <b>unique</b> space\n▪️defend offers form <b>auto</b> deleted* \n(*even it has stop-words)\n\n❗️to order chat-bot-development go to <a href='https://t.me/{1}'>Ferey</a>-studio",
    'es': "🌱 {0}, Bienvenida(o) a <i>lugar de aterrizaje-bot</i> por <code>creando & publicando</code> <b>Telegram</b>-Grupos:\n\n▪️️crear <b>cualquier</b> tipo de oferta (con botones)\n▪️almacenar ofertas en un espacio <b>único</b>\n▪️️defend ofrece formulario <b>auto</b> borrado* \n(*incluso tiene palabras vacías)\n\n❗️para ordenar chat-bot-desarrollo vaya a <a href='https://t.me/{1}'>Ferey</a>-estudio",
    'fr': "🌱 {0}, bienvenue sur <i>landing-bot</i> pour la <code>création et publication</code> <b>Télégramme</b>-channeles:\n\n▪️créer <b>tout </b> type d'offre (avec boutons)\n▪️stocker les offres dans un espace <b>unique</b>\n▪️défendre les offres sous forme <b>auto</b> supprimées* \n(*même si elles ont cessé -words)\n\n❗️pour commander le développement de chat-bot, rendez-vous sur <a href='https://t.me/{1}'>Ferey</a>-studio",
    'zh': "🌱 {0}, 歡迎來到 <i>著陸點-bot</i> 為了 <code>創造 & 張貼</code> <b>Telegram</b>-團體:\n\n▪️️創造 <b>任何</b> 報價類型 (帶按鈕)\n▪️商店優惠在 <b>獨特的</b> 獨特的\n▪️捍衛報價表格自動刪除* \n(*捍衛自動刪除的提議)\n\n❗️訂購 Telegram-bot 去 <a href='https://t.me/{1}'>Ferey</a>-工作室",
    'ar': "🌱 {0} ، مرحبًا بك في <i> برنامج التتبع </i> من أجل الإنشاء والنش Telegram - مجموعات: \n\n▪️ إنشاء <b> أي </b> نوع العرض (مع الأزرار) \n▪️ عروض المتجر في مساحة فريدة \n▪️ الدفاع عن نموذج عروض <b> تلقائي </b> محذوفة * \n (* حتى إذا توقفت -كلمات) \n\n لطلب تطوير chat-bot-انتقل إلى <a href='https://t.me/{1}'>Ferey</a>-studio"
}
l_gen_txt = {
    'ru': "📘 Текст{0}",
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_gen_img = {
    'ru': "🌌 Образ",
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_gen_tlg = {
    'ru': "👩🏽‍💻 Анализ Telegram-канала",
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_main = {
    'ru': '👩🏽‍💻 <b>Выбери режим</b>',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_prompt = {
    'ru': '👩🏽‍💻 <b>Введи</b> запрос для <b>{0}</b> 👇🏼..',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_chn = {
    'ru': '👩🏽‍💻 <b>Вставь</b> ссылку на Telegram канал для анализа финансовых показателей',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_wait = {
    'ru': '👩🏽‍💻 <b>Дождитесь</b> окончания генерации..',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_subcribe = {
    'ru': '👩🏽‍💻 Подождите {0}сек или оформите подписку',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_error = {
    'ru': '👩🏽‍💻 <b>Ошибка</b> генерации',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
l_generate_errchn = {
    'ru': '👩🏽‍💻 <b>Ошибка</b> доступа к каналу (попробуйте позже или сделайте канал публичным)',
    'en': '👩🏽‍💻 <b>Open VPN</b>\n\n*config by special utm link',
    'es': '👇🏽 Elige la dirección',
    'fr': '👇🏽 Choisissez l\'orientation',
    'zh': '👇🏽 選擇方向',
    'ar': '👇🏽 اختر الاتجاه',
}
# endregion


# region post
l_post_text = {
    'ru': "✏️ 1. Напиши мне <b>текст</b> для нового поста (не забудь использовать <i>форматирование</i>)\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 1. Send me <b>text</b> for new post for (don't forget to use <i>formatting</i>)\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 1. Envíame <b>texto</b> para una nueva publicación (no olvides usar <i>formato</i>)\n\n(<i>o haz clic en «➡️️ /Next» para omitir este paso</i>)",
    'fr': "✏️ 1. Envoyez-moi un <b>texte</b> pour un nouveau message (n'oubliez pas d'utiliser le <i>formatage</i>)\n\n(<i>ou cliquez sur le «➡️️ /Next» pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 給我 <b>文本</b> 對於新職位 (不要忘記使用 <i>格式化</i>)\n\n(<i>或單擊 «➡️️/Next» 跳過這一步</i>)",
    'ar': "✏️ 1/3. أرسل لي <b> نصًا </b> للنشر الجديد إلى عن على (لا تنس استخدام <i> تنسيق </i>) \n\n (<i> أو انقر فوق« ➡️️ /Next التالي »لتخطي هذه الخطوة </i>)",
}
l_post_text_limit = {
    'ru': "❗️ Количество <b>символов</b> текста (<i>включая форматирование</i>): <u>{0}</u> больше допустимых 1024",
    'en': "❗️ Number of text-symbols (<i>include formatting</i>): <u>{0}</u> more allowed 1024",
    'es': "❗️ Recuento de símbolos de texto (<i>incluye formato</i>): <u>{0}</u> más 1024 permitidos",
    'fr': "❗️ Nombre de symboles textuels (<i>inclure la mise en forme</i>) : <u>{0}</u> plus autorisé 1024",
    'zh': "❗️ 文本符號數 (<i>包括格式</i>): <u>{0}</u> 更多允許 1024",
    'ar': "❗️ عدد رموز النص (<i> تضمين التنسيق </i>): <u>{0}</u> أكثر مسموحًا بـ 1024",
}
l_post_text_empty = {
    'ru': "❗️ пост пустой, попробуй сначала\n\n{0}",
    'en': "❗️ The post is empty! Please, try again\n\n{0}",
    'es': "❗️ ¡La publicación está vacía! Inténtalo de nuevo\n\n{0}",
    'fr': "❗️ La publication est vide ! Veuillez réessayer\n\n{0}",
    'zh': "❗️ 帖子為空! 請再試一次\n\n{0}",
    'ar': "❗️ المنشور فارغ! من فضلك ، حاول مرة أخرى \n\n{0}",
}
l_post_edit = {
    'ru': "✏️ 1. Отправь измененный <b>текст</b> для текущего поста\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 1. Send changed <b>text</b> for current post\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 1. Envía el <b>texto</b> modificado para la publicación actual\n\n(<i>o haz clic en «➡️️/Next» para omitir este paso</i>)",
    'fr': "✏️ 1. Envoyez le <b>texte</b> modifié pour le message actuel\n\n(<i>ou cliquez sur « ➡️️/Next» pour ignorer cette étape</i>) ",
    'zh': "✏️ 1. 發送更改 <b>文本</b>對於當前職位\n\n(<i>或單擊 «➡️️/Next» 跳過這一步</i>)",
    'ar': "✏️ 1/3. إرسال <b> النص </b> المتغير للمشاركة الحالية \n\n (<i> أو انقر فوق« ➡️️ /Next التالي »لتخطي هذه الخطوة </i>)",
}
l_post_media = {
    'ru': "✏️ 2. Прикрепи <b>медиа</b> контент: фото/гиф/видео/аудио/документ или запиши голосовое/видео-заметку в кружке\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 2. Attach <b>media</b> content: photo/giff/video/audio/document or record voice/video-note\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 2. Adjunte contenido <b>medios</b>: foto/giff/video/audio/documento o grabe voz/video-nota\n\n(<i>o haz clic en «➡️️/Next» para omitir este paso</i>)",
    'fr': "✏️ 2. Joindre du contenu <b>média</b> : photo/gif/vidéo/audio/document ou enregistrer voix/vidéo-note\n\n(<i>ou cliquer sur « ➡️️/Next » pour ignorer cette étape</i>)",
    'zh': "✏️ 2. 附 <b>媒體</b> 內容: 照片/gif/視頻/音頻/文件 或記錄 嗓音/視頻筆記\n\n(<i>或單擊 «➡️️/Next» 跳過這一步</i>)",
    'ar': "✏️ 2/3. أرفق محتوى <b> الوسائط </b>: صورة / giff / فيديو / صوت / مستند أو سجل ملاحظة صوتية / فيديو \n\n (<i> أو انقر فوق« ➡️️ /Next التالي » لتخطي هذه الخطوة </i>) ",
}
l_post_media_wait = {
    'ru': "👩🏽‍💻 Ожидайте обработки {0}..\n#длительность {1}мин",
    'en': "👩🏽‍💻 Processing {0}..\n#duration {1}min",
    'es': "👩🏽‍💻 Procesando {0}..\n#duración {1}min",
    'fr': "👩🏽‍💻 Traitement {0}..\n#durée {1}min",
    'zh': "👩🏽‍💻 加工 {0}..\n#期間 {1}min",
    'ar': "🎥 معالجة {0} .. \n # مدة {1} دقيقة",
}
l_post_media_toobig = {
    'ru': f"👩🏽‍💻 Файл больше 20 Мб, загрузи меньший обьем",
    'en': f"👩🏽‍💻 File more than 20 Mb. Please, reduce size of file",
    'es': f"👩🏽‍💻 Archivo de más de 20 Mb. Por favor, reduzca el tamaño del archivo",
    'fr': f"👩🏽‍💻 Fichier de plus de 20 Mo. Veuillez réduire la taille du fichier",
    'zh': f"👩🏽‍💻 文件超過 20 Mb. 請減小文件大小",
    'ar': f"👩🏽‍💻 الملف أكبر من 20 ميغا بايت. الرجاء تقليل حجم الملف",
}
l_post_tgph = {
    'ru': "✏️ *2. Использовать загруженный <b>media</b>-контент в виде <u>предпросмотра</u> внизу поста (работает только с <i>jpg|png|gif|mp4</i>-файлами до 5Mb)?\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ *2. Whether to use attachment <b>media</b>-content as <u>preview</u> at the bottom of the offer (works only with <i>jpg|png|gif|mp4</i>-formats)?\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ *2. Envía nombres de botones y enlaces para botones (1 o más; haz clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Mi perfil | https://t.me/XXXXX] </code>\n\n\n\n<code>[❤️ Muy interesante][💔 No molestar]</code>\n\n(<i>o haga clic en «➡️️/Next» para omitir esto paso</i>)",
    'fr': "✏️ *2. Envoyez les noms des boutons et les liens pour les boutons (1 ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Mon profil | https://t.me/XXXXX] </code>\n\nили\n\n<code>[❤️ Très intéressant][💔 Ne pas déranger]</code>\n\n(<i>ou cliquez sur « ➡️️/Next » pour ignorer cette étape</i>)",
    'zh': "✏️ *2. 發送按鈕名稱 & 按鈕鏈接 (1 或者更多; 單擊下面的示例進行複制):\n\n<code>[🐳 我的簡歷 | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ 很有意思][💔 請勿打擾]</code>\n\n(<i>或單擊 «➡️️/Next» to skip this step</i>)",
    'ar': "✏️ 3/2. أرسل أسماء الأزرار والروابط للأزرار (1 أو أكثر ؛ انقر على المثال أدناه لنسخه): \n\n <code> [🐳 ملفي الشخصي | https://t.me/XXXXX] </code> \n \n or \n\n <code> [ممتع جدًا] [💔 عدم الإزعاج] </code> \n\n (<i> أو انقر فوق «➡️️ /Next التالي» لتخطي ذلك الخطوة </i>) ",
}
l_post_tgph_yes = {
    'ru': "✅ Да",
    'en': "✅ Yes",
    'es': "✅ Yes",
    'fr': "✅ Yes",
    'zh': "✅ Yes",
    'ar': "✅ Yes",
}
l_post_tgph_no = {
    'ru': "☑️ Нет",
    'en': "☑️ No",
    'es': "☑️ Нет",
    'fr': "☑️ Нет",
    'zh': "☑️ Нет",
    'ar': "☑️ Нет",
}
l_post_button = {
    'ru': "✏️ 3. Отправь <b>названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Ссылка | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ Интересно][💔 Не пишите]</code>\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 3. Send <b>button-names</b> & <b>links</b> for buttons (1 or more; click on the example below to copy):\n\n<code>[🐳 Link | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ Very interesting][💔 Do not disturb]</code>\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 3. Envía nombres de botones y enlaces para botones (1 o más; haz clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Enlace | https://t.me/XXXXX] </code>\n\n\n\n<code>[❤️ Muy interesante][💔 No molestar]</code>\n\n(<i>o haga clic en «➡️️/Next» para omitir esto paso</i>)",
    'fr': "✏️ 3. Envoyez les noms des boutons et les liens pour les boutons (1 ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Lien | https://t.me/XXXXX] </code>\n\nили\n\n<code>[❤️ Très intéressant][💔 Ne pas déranger]</code>\n\n(<i>ou cliquez sur « ➡️️/Next » pour ignorer cette étape</i>)",
    'zh': "✏️ 3. 發送按鈕名稱 & 按鈕鏈接 (1 或者更多; 單擊下面的示例進行複制):\n\n<code>[🐳 關聯 | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ 很有意思][💔 請勿打擾]</code>\n\n(<i>或單擊 «➡️️/Next» to skip this step</i>)",
    'ar': "✏️ 3/3. أرسل أسماء الأزرار والروابط للأزرار (1 أو أكثر ؛ انقر على المثال أدناه لنسخه): \n\n <code> [🐳 صلة | https://t.me/XXXXX] </code> \n \n or \n\n <code> [ممتع جدًا] [💔 عدم الإزعاج] </code> \n\n (<i> أو انقر فوق «➡️️ /Next التالي» لتخطي ذلك الخطوة </i>) ",
}
l_post_button_urlinvalid = {
    'ru': "🔗 Ссылка {0} не действительна",
    'en': "🔗 Url {0} is invalid",
    'es': "🔗 URL {0} no es válida",
    'fr': "🔗L'URL {0} n'est pas valide",
    'zh': "🔗 網址 {0} 無效",
    'ar': "🔗 عنوان {0} غير صالح",
}
l_post_pin = {
    'ru': "✏️ 3. Закреплять (<b>pin</b>) сообщение в канале сверху экрана: <code>да</code> | <code>нет</code>?\n\n(<i>или нажми «➡️️/Next», чтобы <u>не закреплять</u> сообщение</i>)",
    'en': "✏️ 3. Send <b>button-names</b> & <b>links</b> for buttons (1 or more; click on the example below to copy):\n\n<code>[🐳 My profile | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ Very interesting][💔 Do not disturb]</code>\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 3. Envía nombres de botones y enlaces para botones (1 o más; haz clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Mi perfil | https://t.me/XXXXX] </code>\n\n\n\n<code>[❤️ Muy interesante][💔 No molestar]</code>\n\n(<i>o haga clic en «➡️️/Next» para omitir esto paso</i>)",
    'fr': "✏️ 3. Envoyez les noms des boutons et les liens pour les boutons (1 ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Mon profil | https://t.me/XXXXX] </code>\n\nили\n\n<code>[❤️ Très intéressant][💔 Ne pas déranger]</code>\n\n(<i>ou cliquez sur « ➡️️/Next » pour ignorer cette étape</i>)",
    'zh': "✏️ 3. 發送按鈕名稱 & 按鈕鏈接 (1 或者更多; 單擊下面的示例進行複制):\n\n<code>[🐳 我的簡歷 | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ 很有意思][💔 請勿打擾]</code>\n\n(<i>或單擊 «➡️️/Next» to skip this step</i>)",
    'ar': "✏️ 3/3. أرسل أسماء الأزرار والروابط للأزرار (1 أو أكثر ؛ انقر على المثال أدناه لنسخه): \n\n <code> [🐳 ملفي الشخصي | https://t.me/XXXXX] </code> \n \n or \n\n <code> [ممتع جدًا] [💔 عدم الإزعاج] </code> \n\n (<i> أو انقر فوق «➡️️ /Next التالي» لتخطي ذلك الخطوة </i>) ",
}
l_post_date = {
    'ru': "✏️ 4. Выбери дату на календаре\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 4. Send <b>button-names</b> & <b>links</b> for buttons (1 or more; click on the example below to copy):\n\n<code>[🐳 My profile | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ Very interesting][💔 Do not disturb]</code>\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 4. Envía nombres de botones y enlaces para botones (1 o más; haz clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Mi perfil | https://t.me/XXXXX] </code>\n\n\n\n<code>[❤️ Muy interesante][💔 No molestar]</code>\n\n(<i>o haga clic en «➡️️/Next» para omitir esto paso</i>)",
    'fr': "✏️ 4. Envoyez les noms des boutons et les liens pour les boutons (1 ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Mon profil | https://t.me/XXXXX] </code>\n\nили\n\n<code>[❤️ Très intéressant][💔 Ne pas déranger]</code>\n\n(<i>ou cliquez sur « ➡️️/Next » pour ignorer cette étape</i>)",
    'zh': "✏️ 4. 發送按鈕名稱 & 按鈕鏈接 (1 或者更多; 單擊下面的示例進行複制):\n\n<code>[🐳 我的簡歷 | https://t.me/XXXXX]</code>\n\nили\n\n<code>[❤️ 很有意思][💔 請勿打擾]</code>\n\n(<i>或單擊 «➡️️/Next» to skip this step</i>)",
    'ar': "✏️ 3/3. أرسل أسماء الأزرار والروابط للأزرار (1 أو أكثر ؛ انقر على المثال أدناه لنسخه): \n\n <code> [🐳 ملفي الشخصي | https://t.me/XXXXX] </code> \n \n or \n\n <code> [ممتع جدًا] [💔 عدم الإزعاج] </code> \n\n (<i> أو انقر فوق «➡️️ /Next التالي» لتخطي ذلك الخطوة </i>) ",
}
l_post_finish = {
    'ru': "✅ <b>пост готов</b>\n\n<i>Нажми «➡️️/Next», чтобы подтвердить, а затем на кнопку 🔗 Опубликовать</i>",
    'en': "✅ <b>Post is ready</b>\n\n<i>Click the «➡️️/Next» to confirm. Then click the [🔗 Publish]-button</i>",
    'es': "✅ <b>La publicación está lista</b>\n\n<i>Haz clic en «➡️️/Next» para confirmar. Luego haz clic en el botón [🔗 Publicar]</i>",
    'fr': "✅ <b>La publication est prête</b>\n\n<i>Cliquez sur «➡️️/Next» pour confirmer. Cliquez ensuite sur le bouton [🔗 Publier]</i>",
    'zh': "✅ <b>帖子準備好了</b>\n\n<i>點擊 «➡️️/Next» 確認. 然後點擊 [🔗 發布]-按鈕</i>",
    'ar': "✅ <b> النشر جاهز </b> \n\n <i> انقر فوق« ➡️️ /Next التالي »للتأكيد. ثم انقر فوق الزر [🔗 نشر] </i>",
}
l_switch_pm_text = {
    'ru': "🔗 Создать пост с кнопкой",
    'en': "🔗 Create post with buttons",
    'es': "🔗 Crear publicación con botones",
    'fr': "🔗 Créer une publication avec des boutons",
    'zh': "🔗 使用按鈕創建帖子",
    'ar': "🔗 إنشاء منشور باستخدام الأزرار",
}
l_post_new = {
    'ru': "⛰ Создать",
    'en': "⛰ New",
    'es': "⛰ nueva",
    'fr': "⛰ nouvelle",
    'zh': "⛰ 新的",
    'ar': "⛰ الجديد",
}
l_post_delete = {
    'ru': "🚫 Удалить",
    'en': "🚫 Delete",
    'es': "🚫 Borrar",
    'fr': "🚫 Effacer",
    'zh': "🚫 刪除",
    'ar': "🚫 حذف",
}
l_post_change = {
    'ru': "♻️ Изменить",
    'en': "♻️ Edit",
    'es': "♻️ Editar",
    'fr': "♻️ Éditer",
    'zh': "♻️ 編輯",
    'ar': "♻️ تعديل",
}
l_post_publish = {
    'ru': "🔗 Опубликовать",
    'en': "🔗 Publish",
    'es': "🔗 Publicar",
    'fr': "🔗 Publier",
    'zh': "🔗 發布",
    'ar': "🔗 نشر",
}
l_post_pub = {
    'ru': "👩🏽‍💻 Пост опубликован в канале",
    'en': "🔗 Publish",
    'es': "🔗 Publicar",
    'fr': "🔗 Publier",
    'zh': "🔗 發布",
    'ar': "🔗 نشر",
}
l_broadcast_start = {
    'ru': "🗝️ Start..\n#duration {0}min",
    'en': "🗝️ Sending is starting..\n#duration {0}min",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_broadcast_process = {
    'ru': "🗝️ Рассылка..{0}%",
    'en': "🗝️ Sending..{0}%",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_broadcast_send_finish = {
    'ru': "🏁 <b>Рассылка</b> завершена\n\n🗝️ число пользователей, получивших сообщение: <u>{0}</u>",
    'en': "🏁 <b>Sending</b> is finished\n\n🗝️ User count of getting message: <u>{0}</u>",
    'es': "🔙 Volver..",
    'fr': "🔙 Retour..",
    'zh': "🔙 回來..",
    'ar': "🔙 رجوع ..",
}
l_post_btn_answer = {
    'ru': "✅ Пользователь <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>нажал</i> на [<b>{3}</b>] в посте #<u>{4}</u>",
    'en': "✅ The user <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>click</i> the [<b>{3}</b>] of post #<u>{4}</u>",
    'es': "✅ El usuario <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>haga clic</i> en [<b>{3}</b>] de la publicación #<u>{4}</u>",
    'fr': "✅ L'utilisateur <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>clique</i> sur le [<b>{3}</b>] du message #<u>{4}</u>",
    'zh': "✅ 用戶 <b>{0}</b> (username={1}, id=<code>{2}</code>) <i>點擊</i> 上 [<b>{3}</b>] 報價的 #<u>{4}</u>",
    'ar': "✅ المستخدم <b>{0}</b> (اسم المستخدم = {1} ، المعرف = <code>{2}</code>) <i> انقر </i> على [<b>{3}</b>] من المشاركة # <u>{4}</u>",
}
l_post_datetime = {
    'ru': "<b>Дата публикации</b>",
    'en': "<b>Publication Datetime</b>",
    'es': "<b>Creación</b>",
    'fr': "<b>Création</b>",
    'zh': "<b>創建</b>",
    'ar': "<b> إنشاء </b>",
}
l_post_preview = {
    'ru': "<b>Превью</b>",
    'en': "<b>Preview</b>",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_post_buttons = {
    'ru': "<b>Кнопки</b>",
    'en': "<b>Buttons</b>",
    'es': "<b>Botones</b>",
    'fr': "<b>Boutons</b>",
    'zh': "<b>鈕扣</b>",
    'ar': "<b> الأزرار </b>",
}
l_post_pins = {
    'ru': "<b>Закреп</b>",
    'en': "<b>Pin</b>",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}

l_btn = {
    'ru': "кнопки",
    'en': "buttons",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_pin = {
    'ru': "закреп",
    'en': "pin",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_silence = {
    'ru': "тихо",
    'en': "silence",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_gallery = {
    'ru': "галерея",
    'en': "preview",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_preview = {
    'ru': "превью",
    'en': "preview",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_spoiler = {
    'ru': "спойлер",
    'en': "preview",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_buttons_text = {
    'ru': "👩🏽‍💻 Режим [кнопки] доступен, если создана хотя бы 1 кнопка при создании поста",
    'en': "👩🏽‍💻 [preview] mode isavailable only with unique jpg|png|gif|mp4-files before 5Mb",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_preview_text = {
    'ru': "👩🏽‍💻 Режим [превью] используется с одиночными jpg|png|gif|mp4-файлами до 5Mb",
    'en': "👩🏽‍💻 [preview] mode isavailable only with unique jpg|png|gif|mp4-files before 5Mb",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_gallery_text = {
    'ru': "👩🏽‍💻 Режим [галерея] доступен для 2 и более медиа файлов",
    'en': "👩🏽‍💻 [preview] mode isavailable only with unique jpg|png|gif|mp4-files before 5Mb",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_spoiler_text = {
    'ru': "👩🏽‍💻 Режим [спойлер] доступен для photo/gif/video",
    'en': "👩🏽‍💻 [preview] mode isavailable only with unique jpg|png|gif|mp4-files before 5Mb",
    'es': "<b>Enlace</b>",
    'fr': "<b>Lien</b>",
    'zh': "<b>關聯</b>",
    'ar': "<b> ارتباط </b>",
}
l_post_has_restricted = {
    'ru': "👩🏽‍💻 В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить <code>видео-заметку</code>/<code>голосовое</code>",
    'en': "off",
    'es': "apagada",
    'fr': "à l'arrêt",
    'zh': "離開",
    'ar': "إيقاف",
}
l_post_tz = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 Текущее время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "no",
    'es': "no",
    'fr': "non",
    'zh': "不",
    'ar': "رقم",
}
l_post_time_future = {
    'ru': "🕒 Укажи время в будущем",
    'en': "🕒 Specify a time in the future",
    'es': "🕒 Especificar un tiempo en el futuro",
    'fr': "🕒 Spécifiez une heure dans le futur",
    'zh': "🕒 指定未來的時間",
    'ar': "🕒 حدد وقتًا في المستقبل",
}
# endregion
